
/*
 * de.unkrig.commons - A general-purpose Java class library
 *
 * Copyright (c) 2011, Arno Unkrig
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *    1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
 *       following disclaimer.
 *    2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *       following disclaimer in the documentation and/or other materials provided with the distribution.
 *    3. The name of the author may not be used to endorse or promote products derived from this software without
 *       specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.unkrig.commons.util.tool.simplelogging;

import java.io.File;
import java.util.logging.Level;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;

import de.unkrig.commons.nullanalysis.Nullable;
import de.unkrig.commons.util.logging.SimpleLogging;

public
class AntTask extends Task {

    private @Nullable File    out;
    private boolean           stdout;
    private @Nullable Level   level;
    private @Nullable Boolean noWarn, quiet, normal, verbose, debug;

    // BEGIN CONFIGURATION SETTERS

    public void
    setOut(File value) {
        this.out = value;
    }

    public void
    setStdout(boolean value) {
        this.stdout = value;
    }

    public void
    setLevel(String value) {
        this.level = Level.parse(value);
    }

    public void
    setNoWarn(boolean value) {
        this.noWarn = value;
    }

    public void
    setQuiet(boolean value) {
        this.quiet = value;
    }

    public void
    setNormal(boolean value) {
        this.normal = value;
    }

    public void
    setVerbose(boolean value) {
        this.verbose = value;
    }

    public void
    setDebug(boolean value) {
        this.debug = value;
    }

    // END CONFIGURATION SETTERS

    /**
     * The ANT task "execute" method.
     *
     * @see Task#execute()
     */
    @Override public void
    execute() throws BuildException {
        try {
            if (this.out != null) SimpleLogging.setOut(this.out);

            if (this.stdout) SimpleLogging.setStdout();

            if (this.level != null) SimpleLogging.setLevel(this.level);

            if (this.noWarn  == Boolean.TRUE) SimpleLogging.setNoWarn();
            if (this.quiet   == Boolean.TRUE) SimpleLogging.setQuiet();
            if (this.normal  == Boolean.TRUE) SimpleLogging.setNormal();
            if (this.verbose == Boolean.TRUE) SimpleLogging.setVerbose();
            if (this.debug   == Boolean.TRUE) SimpleLogging.setDebug();
        } catch (Exception e) {
            throw new BuildException(e);
        }
    }
}
